@@ -3,7 +3,9 @@ def fetch_model(name):
     """
     Return the model class for ``name`` in the following format:
     (name = app.model) -- Example:  (name = profile.UserProfile)
-    If not profile found , None is returned
+    Or  return None
     """
     if name:
          return get_model(*name.split('.'))
+    return None
+
